WhateverResult

Type Alias WhateverResult 

pub type WhateverResult<T> = Result<T, Whatever>;
A simple Result of which the error is convertible from ErrorExt (which every GreptimeDB error implements). Use this if you are tired of writing unwraps in test codes, that you can use the ? on all GreptimeDB errors.

Aliased Type

pub enum WhateverResult<T> {
    Ok(T),
    Err(Whatever),
}

Variants

1.0.0

Ok(T)

Contains the success value

1.0.0

Err(Whatever)

Contains the error value