pub type WhateverResult<T> = Result<T, Whatever>;
A simple Result of which the error is convertible from ErrorExt (which every GreptimeDB error implements). Use this if you are tired of writing unwraps in test codes, that you can use the ? on all GreptimeDB errors.
unwrap
?
pub enum WhateverResult<T> { Ok(T), Err(Whatever), }
Contains the success value
Contains the error value